##
#' Example data containing case and control data
#'
#' This data contains 136 marker variables for 68 individuals who are distinguished as case/control.
#'
#' @docType data
#' @keywords datasets
#' @name CaseControl
#' @usage data(CaseControl)
#' @format A data frame with 136 marker variables and 68 individuals.
"CaseControl"